@@ -24,11 +24,11 @@
 class FormattedSpinBox : public QDoubleSpinBox
 {
 public:
-    FormattedSpinBox(QWidget* parent = NULL) : QDoubleSpinBox(parent) {}
+    FormattedSpinBox(QWidget* parent = nullptr) : QDoubleSpinBox(parent) {}
 
 public:
-    virtual QString textFromValue(double value) const;
-    virtual double valueFromText(const QString& text) const;
+    QString textFromValue(double value) const override;
+    double valueFromText(const QString& text) const override;
 
 private:
     QString stripped(const QString &t, int *pos = 0) const;
