@@ -35,15 +35,11 @@ class KActionCollection;
 */
 class ListOperations : public QWidget, public Ui::ListOperationsBase
 {
-    Q_OBJECT
     Q_DISABLE_COPY(ListOperations)
 
 public:
     ListOperations(QWidget* parent = nullptr);
 
-Q_SIGNALS:
-    void contextMenuRequested(const QPoint&);
-
 public:
     void setActionCollection(KActionCollection* coll) {
         m_ActionCollection = coll;
@@ -51,22 +47,22 @@ public:
 
     void updateOperations(const OperationStack::Operations& ops);
 
+    QListWidget& listOperations() {
+        Q_ASSERT(m_ListOperations);
+        return *m_ListOperations;
+    }
+
 protected:
     KActionCollection* actionCollection() {
         return m_ActionCollection;
     }
 
-    QListWidget& listOperations() {
-        Q_ASSERT(m_ListOperations);
-        return *m_ListOperations;
-    }
     const QListWidget& listOperations() const {
         Q_ASSERT(m_ListOperations);
         return *m_ListOperations;
     }
 
-protected Q_SLOTS:
-    void on_m_ListOperations_customContextMenuRequested(const QPoint& pos);
+    void customContextMenuRequested(const QPoint& pos);
 
 private:
     KActionCollection* m_ActionCollection;
