@@ -44,11 +44,13 @@ protected:
     void onRoleChanged(bool);
     void onFilesystemChanged(int);
     void onLabelChanged(const QString& newLabel);
+    void onLVNameChanged(const QString& newName);
 
     void setupConnections() override;
     void setupDialog() override;
     void slotPasswordStatusChanged();
     void updateHideAndShow();
+    void updateOkButtonStatus();
     void updateFileSystem(FileSystem::Type t);
     PartitionRole::Roles partitionRoles() const {
         return m_PartitionRoles;
@@ -59,12 +61,19 @@ protected:
     bool canShrink() const override {
         return true;
     }
-    bool canMove() const override {
-        return true;
+    bool canMove() const override;
+
+    bool isValidPassword() const {
+        return m_IsValidPassword;
+    }
+    bool isValidLVName() const {
+        return m_IsValidLVName;
     }
 
 private:
     PartitionRole::Roles m_PartitionRoles;
+    bool m_IsValidPassword;
+    bool m_IsValidLVName;
 };
 
 #endif
