@@ -22,10 +22,10 @@
 #include <KLocalizedString>
 
 #include <QStyledItemDelegate>
+#include <QStyleOptionViewItem>
 #include <QPainter>
-#include <QTextDocument>
-#include <QAbstractTextDocumentLayout>
 #include <QPoint>
+#include <QTextDocument>
 
 #include <config.h>
 
@@ -43,7 +43,7 @@ void SmartAttrDelegate::paint(QPainter* painter, const QStyleOptionViewItem& opt
 
     painter->save();
 
-    QStyleOptionViewItemV4 opt = option;
+    QStyleOptionViewItem opt = option;
     initStyleOption(&opt, index);
 
     QApplication::style()->drawPrimitive(QStyle::PE_PanelItemViewItem, &opt, painter);
