@@ -17,8 +17,8 @@
  *************************************************************************/
 
 #include "gui/treelog.h"
-
 #include "gui/partitionmanagerwidget.h"
+#include "config.h"
 
 #include <util/globallog.h>
 #include <util/helpers.h>
@@ -38,8 +38,6 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 
-#include <config.h>
-
 /** Creates a new TreeLog instance.
     @param parent the parent widget
 */
@@ -137,7 +135,7 @@ void TreeLog::onSaveLog()
         KIO::CopyJob* job = KIO::move(QUrl::fromLocalFile(tempFile.fileName()), url, KIO::HideProgressInfo);
         job->exec();
         if (job->error())
-            job->ui()->showErrorMessage();
+            job->uiDelegate()->showErrorMessage();
     }
 }
 
